#
# spec file for package libfwps
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libfwps
%define lname	libfwps1
Version:        20240120
Release:        2.1
Summary:        Library for Windows Property Store data types
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libfwps
Source:         https://github.com/libyal/libfwps/releases/download/%version/libfwps-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libfwps/releases/download/%version/libfwps-alpha-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcdata) >= 20240103
BuildRequires:  pkgconfig(libcerror) >= 20240101
BuildRequires:  pkgconfig(libclocale) >= 20240107
BuildRequires:  pkgconfig(libcnotify) >= 20240108
BuildRequires:  pkgconfig(libcthreads) >= 2024012
BuildRequires:  pkgconfig(libfdatetime) >= 20240115
BuildRequires:  pkgconfig(libfguid) >= 20240116
BuildRequires:  pkgconfig(libfole) >= 20240119
BuildRequires:  pkgconfig(libuna) >= 20230710
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libfwps is a library for Windows Property Store data types.

Part of the libyal family of libraries.

%package -n %lname
Summary:        Library for Windows Property Store data types
Group:          System/Libraries

%description -n %lname
libfwps is a library for Windows Property Store data types.

Part of the libyal family of libraries.

%package devel
Summary:        Development files for libfwps
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libfwps is a library for Windows Property Store data types.

This subpackage contains libraries and header files for developing
applications that want to make use of libfwps.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libfwps.so.*

%files -n %name-devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/*.3*

%files %python_files
%python_sitearch/*.so

%changelog
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sat Jan 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240120
  * Support unpaired UTF-16 surrogates
* Mon Nov 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231126
  * Build system updates only
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Wed Jul 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230711
  * New APIs: Moved path string to separate functions
  * Python bindings were updated
* Sun Feb  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to relesae 20230202
  * Python bindings were updated
* Mon Jan 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230130
  * Python bindings were updated
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220122
  * No changelog was provided
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package for build.opensuse.org
  (version 20210421/commit 5d59f5bf)
- Add system-libs.patch
